@@ -47,6 +47,8 @@ case "$1" in
         set -e
 
         chown $WWW_USER "$VAR_DIR/$USER_DB"
+        # benno-imap -> user writes db-entries
+        chmod u=rwx,g=rwx,o= "$VAR_DIR"
         chmod u=rw,g=rw,o= "$VAR_DIR/$USER_DB"
 
         if [ -e /usr/share/apache2/apache2-maintscript-helper ];then
