@@ -110,7 +110,10 @@ try {
     $searchMaskState = $AppState->getValue('searchMaskState','Simple');
     $App->setSession('searchMaskState',$searchMaskState);
 
-    // current archive
+    // set current archive
+    if (!in_array($AppState->getValue('archive'),$archive_list)) {
+        $AppState->saveValue('archive','');
+    }
     if (!$archive = $AppState->getValue('archive')) {
         $archive = end($archive_list);
     }
